.. _bokeh:

bokeh
=====

The ``bokeh`` module itself contains a few useful functions and attributes:

.. attribute:: __version__
  :annotation: = currently installed version of Bokeh

.. autofunction:: bokeh.license

.. autofunction:: bokeh.test
